@@ -111,16 +111,6 @@ class FileSystemManager():
                  'msdos': '83',
                  'compress': None,
                  'type': ['hdd', 'usb-hdd']},
-        'ext4-fast-commit': {'defaultopt': defaultOpt,
-                 'format': '/sbin/mkfs.ext4',
-                 'orig': 'ext4',
-                 'formatparam': '-O fast_commit {labelparam} {device}',
-                 'gpt': '8300',
-                 'label': '-L {labelname}',
-                 'ssd': [],
-                 'msdos': '83',
-                 'compress': None,
-                 'type': ['hdd', 'usb-hdd']},
         'ext3': {'defaultopt': defaultOpt,
                  'format': '/sbin/mkfs.ext3',
                  'formatparam': '{labelparam} {device}',
