@@ -670,7 +670,7 @@ class Install(MethodsInterface):
         Скопировать прочие настройки из текущей системы в новую
         """
         file_mask = re.compile("(/etc/ssh/ssh_host_.*|"
-                               "/root/.ssh/(id_.*|known_hosts))")
+                               "/root/.ssh/(id_.*|known_hosts))(?!\.old)")
         target_dir = target.getDirectory()
         source_dir = source.getDirectory()
         for f in (x for x 
